@@ -4,7 +4,7 @@
  * Created Date: 27/05/2021
  * Author: Shun Suzuki
  * -----
- * Last Modified: 30/05/2021
+ * Last Modified: 18/06/2021
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
  * Copyright (c) 2021 Hapis Lab. All rights reserved.
@@ -12,9 +12,7 @@
  */
 
 use anyhow::Result;
-use autd3_core::{
-    configuration::Configuration, hardware_defined::MOD_FRAME_SIZE, modulation::Modulation,
-};
+use autd3_core::modulation::Modulation;
 use autd3_traits::Modulation;
 
 /// Static amplitude
@@ -22,6 +20,7 @@ use autd3_traits::Modulation;
 pub struct Static {
     buffer: Vec<u8>,
     sent: usize,
+    sampling_freq_div: u16,
 }
 
 impl Static {
@@ -38,13 +37,14 @@ impl Static {
     ///
     pub fn with_duty(duty: u8) -> Self {
         Self {
-            buffer: vec![duty; MOD_FRAME_SIZE],
+            buffer: vec![duty; 1],
             sent: 0,
+            sampling_freq_div: 10,
         }
     }
 
     #[allow(clippy::unnecessary_wraps)]
-    fn calc(&mut self, _config: Configuration) -> Result<()> {
+    fn calc(&mut self) -> Result<()> {
         Ok(())
     }
 }
